@@ -517,8 +517,23 @@ struct network_info *known_networks_find(const char *ssid,
 	return l_queue_find(known_networks, network_info_match, &query);
 }
 
+static void known_network_append_frequencies(const struct network_info *info,
+						struct scan_freq_set *set,
+						uint8_t max)
+{
+	const struct l_queue_entry *entry;
+
+	for (entry = l_queue_get_entries(info->known_frequencies); entry && max;
+					entry = entry->next, max--) {
+		const struct known_frequency *known_freq = entry->data;
+
+		scan_freq_set_add(set, known_freq->frequency);
+	}
+}
+
 struct scan_freq_set *known_networks_get_recent_frequencies(
-						uint8_t num_networks_tosearch)
+						uint8_t num_networks_tosearch,
+						uint8_t freqs_per_network)
 {
 	/*
 	 * This search function assumes that the known networks are always
@@ -527,10 +542,9 @@ struct scan_freq_set *known_networks_get_recent_frequencies(
 	 * list.
 	 */
 	const struct l_queue_entry *network_entry;
-	const struct l_queue_entry *freq_entry;
 	struct scan_freq_set *set;
 
-	if (!num_networks_tosearch)
+	if (!num_networks_tosearch || !freqs_per_network)
 		return NULL;
 
 	set = scan_freq_set_new();
@@ -541,14 +555,8 @@ struct scan_freq_set *known_networks_get_recent_frequencies(
 						num_networks_tosearch--) {
 		const struct network_info *network = network_entry->data;
 
-		for (freq_entry = l_queue_get_entries(
-						network->known_frequencies);
-				freq_entry; freq_entry = freq_entry->next) {
-			const struct known_frequency *known_freq =
-							freq_entry->data;
-
-			scan_freq_set_add(set, known_freq->frequency);
-		}
+		known_network_append_frequencies(network, set,
+							freqs_per_network);
 	}
 
 	return set;
